=== modified file 'bzrlib/errors.py'
--- bzrlib/errors.py	2008-01-11 05:08:20 +0000
+++ bzrlib/errors.py	2008-01-30 15:54:33 +0000
@@ -2510,6 +2510,11 @@
         self.name = name
 
 
+class NoTemplate(BzrError):
+
+    _fmt = 'No template specified.'
+
+
 class UnableCreateSymlink(BzrError):
 
     _fmt = 'Unable to create symlink %(path_str)son this platform'

=== modified file 'bzrlib/tests/blackbox/test_version_info.py'
--- bzrlib/tests/blackbox/test_version_info.py	2007-06-26 20:32:49 +0000
+++ bzrlib/tests/blackbox/test_version_info.py	2008-01-30 15:54:33 +0000
@@ -134,3 +134,8 @@
         txt = self.run_bzr('version-info --format python branch')[0]
 
         self.assertContainsRe(txt, 'version_info = {')
+
+    def test_custom_without_template(self):
+        wt = self.make_branch_and_tree('branch')
+        out, err = self.run_bzr('version-info --custom', retcode=3)
+        self.assertContainsRe(err, r'ERROR: No template specified\.')

=== modified file 'bzrlib/tests/test_version_info.py'
--- bzrlib/tests/test_version_info.py	2007-12-21 15:05:25 +0000
+++ bzrlib/tests/test_version_info.py	2008-01-30 15:54:33 +0000
@@ -22,6 +22,7 @@
 import sys
 
 from bzrlib import (
+    errors,
     symbol_versioning,
     tests,
     version_info_formats,
@@ -257,6 +258,11 @@
         self.assertEqual(val, 'clean: 0')
         os.remove('branch/c')
 
+    def test_custom_without_template(self):
+        builder = CustomVersionInfoBuilder(None)
+        sio = StringIO()
+        self.assertRaises(errors.NoTemplate, builder.generate, sio)
+
 
 class TestBuilder(version_info_formats.VersionInfoBuilder):
     pass

=== modified file 'bzrlib/version_info_formats/format_custom.py'
--- bzrlib/version_info_formats/format_custom.py	2007-12-17 17:23:21 +0000
+++ bzrlib/version_info_formats/format_custom.py	2008-01-30 15:54:33 +0000
@@ -79,6 +79,9 @@
     """Create a version file based on a custom template."""
 
     def generate(self, to_file):
+        if self._template is None:
+            raise errors.NoTemplate()
+
         info = Template()
         info.add('build_date', create_date_str())
         info.add('branch_nick', self._branch.nick)

